//
//  YHCertificateInfoCell.swift
//  galaxy
//
//  Created by edy on 2024/3/13.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit
import AttributedString


class YHCertificateInfoCell: UITableViewCell {

    
    static let cellReuseIdentifier = "YHCertificateNameCell"
    
    var status : YHCertificateUploadStatus = .preUpload
    var templateBlock:(()->())?
    var whiteView: UIView!
    var nameTextView: UITextView!
    var infoLabel: UILabel!
    var statusLabel: UILabel!
    var rightArrowImgV: UIImageView!
    
    private lazy var templateLabel : UILabel = {
        let label = UILabel(frame: CGRect(x: 0, y: 0, width: 48, height: 16))
        label.text = "资料模版"
        label.font = .PFSC_M(ofSize: 10)
        label.backgroundColor = .brandMainColor8
        label.textColor = .brandMainColor
        label.layer.cornerRadius = 3
        label.clipsToBounds = true
        label.textAlignment = .center
        label.isUserInteractionEnabled = true
        let tap = UITapGestureRecognizer(target: self, action: #selector(didTemplateBtnClicked))
        label.addGestureRecognizer(tap)
        return label
    }()

    required init?(coder: NSCoder) {
        super.init(coder: coder)
    }
    
    override init(style: UITableViewCell.CellStyle, reuseIdentifier: String?) {
        super.init(style: style, reuseIdentifier: reuseIdentifier)
        setupUI()
    }
    
    func updateModel(_ model: YHSupplementInfo) {
        
        if let status = YHCertificateUploadStatus(rawValue: model.checkStatus) {
            
            var titleColor: UIColor = .labelTextColor2
            var title = ""
            switch status  {
            case .preUpload:
                titleColor = .brandMainColor
                title = "待上传".local
            case .rejected:
                titleColor = .failColor
                title = "已驳回".local
            case .review:
                titleColor = .labelTextColor2
                title = "审核中".local
            case .finish:
                titleColor = .labelTextColor2
                title = "已通过".local
            case .all:
                titleColor = .labelTextColor2
            }
            statusLabel.text = title
            statusLabel.textColor = titleColor
        }
        
        if model.templateInfo.materialPath.isEmpty && model.templateInfo.guideFilePath.isEmpty && model.templateInfo.description.isEmpty {
            
            nameTextView.attributed.text = """
            \(model.name, .foreground(UIColor.mainTextColor), .font(UIFont.PFSC_M(ofSize: 16)))
            """
            
        } else {
            nameTextView.attributed.text = """
            \(model.name, .foreground(UIColor.mainTextColor), .font(UIFont.PFSC_M(ofSize: 16)))  \(.view(templateLabel, .original(.center)))
            """
        }
        infoLabel.text = "类型: \(model.typeName) 所属人: \(model.nameExtra.userName)"
    }
    
    @objc func didTemplateBtnClicked() {
        if let templateBlock = templateBlock {
            templateBlock()
        }
    }
    
    func setupUI() {
        
        self.selectionStyle = .none
        contentView.backgroundColor = UIColor(hexString:"#F8F8F8")
        
        whiteView = UIView()
        whiteView.layer.cornerRadius = 6.0
        whiteView.clipsToBounds = true
        whiteView.backgroundColor = .white
        contentView.addSubview(whiteView)
        
        nameTextView = UITextView()
        nameTextView.textColor = UIColor.mainTextColor
        nameTextView.font = UIFont.PFSC_M(ofSize: 16)
        nameTextView.isScrollEnabled = false
        nameTextView.isEditable = false
        nameTextView.isSelectable = false
        whiteView.addSubview(nameTextView)
        
        nameTextView.attributed.text = """
        \("资料名称", .foreground(UIColor.mainTextColor), .font(UIFont.PFSC_M(ofSize: 16)))  \(.view(templateLabel, .original(.center)))
        """
        
        infoLabel = UILabel()
        infoLabel.textColor = UIColor.labelTextColor2
        infoLabel.textAlignment = .left
        infoLabel.font = UIFont.PFSC_R(ofSize:11)
        infoLabel.numberOfLines = 0
        whiteView.addSubview(infoLabel)
        
        statusLabel = UILabel()
        statusLabel.textColor = UIColor.labelTextColor2
        statusLabel.textAlignment = .left
        statusLabel.font = UIFont.PFSC_R(ofSize:14)
        whiteView.addSubview(statusLabel)
        
        rightArrowImgV = UIImageView(image: UIImage(named: "service_center_right_next_icon"))
        whiteView.addSubview(rightArrowImgV)
        
        whiteView.snp.makeConstraints { make in
            make.left.equalToSuperview().offset(20)
            make.right.equalToSuperview().offset(-20)
            make.top.bottom.equalToSuperview()
        }
        
        nameTextView.snp.makeConstraints { make in
            make.left.equalToSuperview().offset(10)
            make.top.equalToSuperview().offset(4)
            make.right.equalTo(statusLabel.snp.left).offset(-6)
        }
        
        infoLabel.snp.makeConstraints { make in
            make.left.equalToSuperview().offset(16)
            make.right.equalTo(nameTextView)
            make.top.equalTo(nameTextView.snp.bottom)
            make.bottom.equalToSuperview().offset(-12)
            make.height.equalTo(20)
        }
        
        statusLabel.snp.makeConstraints { make in
            make.right.equalTo(rightArrowImgV.snp.left).offset(-6)
            make.size.equalTo(CGSize(width: 42, height: 20))
            make.centerY.equalToSuperview()
        }
        
        rightArrowImgV.snp.makeConstraints { make in
            make.right.equalToSuperview().offset(-16)
            make.size.equalTo(CGSize(width: 16, height: 16))
            make.centerY.equalToSuperview()
        }
    }

}
